Class: CraftBook::NBT::ByteTag

Inherits:
ValueTag show all
Defined in:
lib/craftbook/nbt/byte_tag.rb

Overview

A tag type representing an 8-bit signed integer in the range of -128 and 127 inclusive.

Constant Summary collapse

MIN =

The minimum permissible value for this type.

-0x80
MAX =

The maximum permissible value for this type.

0x7F

Constants inherited from Tag

Tag::TYPE_BYTE, Tag::TYPE_BYTE_ARRAY, Tag::TYPE_COMPOUND, Tag::TYPE_DOUBLE, Tag::TYPE_END, Tag::TYPE_FLOAT, Tag::TYPE_INT, Tag::TYPE_INT_ARRAY, Tag::TYPE_LIST, Tag::TYPE_LONG, Tag::TYPE_LONG_ARRAY, Tag::TYPE_SHORT, Tag::TYPE_STRING

Instance Attribute Summary collapse

Attributes inherited from Tag

#name, #type

Instance Method Summary collapse

Methods inherited from ValueTag

#to_h

Methods inherited from Tag

parse, #pretty, #pretty_print, #to_h, #to_json

Constructor Details

#initialize(name, value = 0) ⇒ ByteTag

Note:

Values of true and false will be converted to 1 and 0 respectfully.

Creates a new instance of the DoubleTag class.



30
31
32
# File 'lib/craftbook/nbt/byte_tag.rb', line 30

def initialize(name, value = 0)
  super(TYPE_BYTE, name, value)
end

Instance Attribute Details

#valueNumeric, Boolean

The value of the tag. Values of true and false will be converted to 1 and 0 respectfully.



# File 'lib/craftbook/nbt/byte_tag.rb', line 18

Instance Method Details

#boolBoolean

Returns the value of the tag as boolean.



44
45
46
# File 'lib/craftbook/nbt/byte_tag.rb', line 44

def bool
  @value != 0
end

#stringifyString

Returns the NBT tag as an SNBT string.



56
57
58
# File 'lib/craftbook/nbt/byte_tag.rb', line 56

def stringify
  "#{snbt_prefix}#{@value}B"
end

#to_sString

Returns the NBT tag as a formatted and human-readable string.



50
51
52
# File 'lib/craftbook/nbt/byte_tag.rb', line 50

def to_s
  "TAG_Byte(#{@name ? "\"#{@name}\"" : 'None'}): #{@value}"
end